Trove Style Commandments
========================

- Step 1: Read the OpenStack Style Commandments
  https://docs.openstack.org/hacking/latest
- Step 2: Read on

Trove Specific Commandments
---------------------------

None so far

